# sciutil

[![codecov.io](https://codecov.io/github/ArianeMora/sciutil/coverage.svg?branch=master)](https://codecov.io/github/ArianeMora/sciutil?branch=master)
[![PyPI](https://img.shields.io/pypi/v/sciutil)](https://pypi.org/project/sciutil/)

Utility functions for my sci* packages.

## Installation
* PyPI: `pip install sciutil`

## Usage
Create an instance of SciUtil class with your chosen configs (or none for the default) and use the helper 
functions to print coloured messages, save data and generate labels.

Run `python -m sciutil` for help and list of functions.